<a id="mypy-boto3-accessanalyzer"></a>

# mypy-boto3-accessanalyzer

[![PyPI - types-aiobotocore-accessanalyzer](https://img.shields.io/pypi/v/types-aiobotocore-accessanalyzer.svg?color=blue)](https://pypi.org/project/types-aiobotocore-accessanalyzer)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/types-aiobotocore-accessanalyzer.svg?color=blue)](https://pypi.org/project/types-aiobotocore-accessanalyzer)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/types-aiobotocore-accessanalyzer?color=blue)](https://pypistats.org/packages/types-aiobotocore-accessanalyzer)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[boto3.AccessAnalyzer 1.20.47](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/accessanalyzer.html#AccessAnalyzer)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 6.4.2](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[types-aiobotocore-accessanalyzer docs](https://vemel.github.io/types_aiobotocore_docs/types_aiobotocore_accessanalyzer/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/main/demo.gif)

- [mypy-boto3-accessanalyzer](#mypy-boto3-accessanalyzer)
  - [How to install](#how-to-install)
    - [VSCode extension](#vscode-extension)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)

<a id="how-to-install"></a>

## How to install

<a id="vscode-extension"></a>

### VSCode extension

Add
[AWS Boto3](https://marketplace.visualstudio.com/items?itemName=Boto3typed.boto3-ide)
extension to your VSCode and run `AWS boto3: Quick Start` command.

Click `Modify` and select `boto3 common` and `AccessAnalyzer`.

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `types-aiobotocore` for `AccessAnalyzer` service.

```bash
python -m pip install types-aiobotocore[accessanalyzer]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `types-aiobotocore[accessanalyzer]` in your environment:
  `python -m pip install 'types-aiobotocore[accessanalyzer]'`

Both type checking and auto-complete should work for `AccessAnalyzer` service.
No explicit type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `types-aiobotocore[accessanalyzer]` in your environment:
  `python -m pip install 'types-aiobotocore[accessanalyzer]'`

Both type checking and auto-complete should work for `AccessAnalyzer` service.
No explicit type annotations required, write your `aiobotocore` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`types-aiobotocore` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `types-aiobotocore[accessanalyzer]` in your environment:
  `python -m pip install 'types-aiobotocore[accessanalyzer]'`
- Run `mypy` as usual

Type checking should work for `AccessAnalyzer` service. No explicit type
annotations required, write your `aiobotocore` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `types-aiobotocore[accessanalyzer]` in your environment:
  `python -m pip install 'types-aiobotocore[accessanalyzer]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `AccessAnalyzer` service. No explicit type
annotations required, write your `aiobotocore` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`AccessAnalyzerClient` provides annotations for
`session.create_client("accessanalyzer")`.

```python
from aiobotocore.session import get_session

from types_aiobotocore_accessanalyzer import AccessAnalyzerClient

session = get_session()
with async session.create_client("accessanalyzer") as client:
    client: AccessAnalyzerClient
    # now client usage is checked by mypy and IDE should provide code auto-complete
```

<a id="paginators-annotations"></a>

### Paginators annotations

`types_aiobotocore_accessanalyzer.paginator` module contains type annotations
for all paginators.

````python
from aiobotocore.session import get_session

from types_aiobotocore_accessanalyzer import AccessAnalyzerClient
from types_aiobotocore_accessanalyzer.paginator import (
    ListAccessPreviewFindingsPaginator,
    ListAccessPreviewsPaginator,
    ListAnalyzedResourcesPaginator,
    ListAnalyzersPaginator,
    ListArchiveRulesPaginator,
    ListFindingsPaginator,
    ListPolicyGenerationsPaginator,
    ValidatePolicyPaginator,
)

session = get_session()
with async session.create_client("accessanalyzer") as client:
    client: AccessAnalyzerClient

    # Explicit type annotations are optional here
    # Type should be correctly discovered by mypy and IDEs
    # VSCode requires explicit type annotations
        list_access_preview_findings_paginator: ListAccessPreviewFindingsPaginator = client.get_paginator("list_access_preview_findings")
        list_access_previews_paginator: ListAccessPreviewsPaginator = client.get_paginator("list_access_previews")
        list_analyzed_resources_paginator: ListAnalyzedResourcesPaginator = client.get_paginator("list_analyzed_resources")
        list_analyzers_paginator: ListAnalyzersPaginator = client.get_paginator("list_analyzers")
        list_archive_rules_paginator: ListArchiveRulesPaginator = client.get_paginator("list_archive_rules")
        list_findings_paginator: ListFindingsPaginator = client.get_paginator("list_findings")
        list_policy_generations_paginator: ListPolicyGenerationsPaginator = client.get_paginator("list_policy_generations")
        validate_policy_paginator: ValidatePolicyPaginator = client.get_paginator("validate_policy")
    ```







### Literals

`types_aiobotocore_accessanalyzer.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from types_aiobotocore_accessanalyzer.literals import (
    AccessPreviewStatusReasonCodeType,
    AccessPreviewStatusType,
    AclPermissionType,
    AnalyzerStatusType,
    FindingChangeTypeType,
    FindingSourceTypeType,
    FindingStatusType,
    FindingStatusUpdateType,
    JobErrorCodeType,
    JobStatusType,
    KmsGrantOperationType,
    ListAccessPreviewFindingsPaginatorName,
    ListAccessPreviewsPaginatorName,
    ListAnalyzedResourcesPaginatorName,
    ListAnalyzersPaginatorName,
    ListArchiveRulesPaginatorName,
    ListFindingsPaginatorName,
    ListPolicyGenerationsPaginatorName,
    LocaleType,
    OrderByType,
    PolicyTypeType,
    ReasonCodeType,
    ResourceTypeType,
    TypeType,
    ValidatePolicyFindingTypeType,
    ValidatePolicyPaginatorName,
    ValidatePolicyResourceTypeType,
    ServiceName,
    PaginatorName,
)

def check_value(value: AccessPreviewStatusReasonCodeType) -> bool:
    ...
````

### Typed dictionaries

`types_aiobotocore_accessanalyzer.type_defs` module contains structures and
shapes assembled to typed dictionaries for additional type checking.

```python
from types_aiobotocore_accessanalyzer.type_defs import (
    AccessPreviewFindingTypeDef,
    AccessPreviewStatusReasonTypeDef,
    AccessPreviewSummaryTypeDef,
    AccessPreviewTypeDef,
    AclGranteeTypeDef,
    AnalyzedResourceSummaryTypeDef,
    AnalyzedResourceTypeDef,
    AnalyzerSummaryTypeDef,
    ApplyArchiveRuleRequestRequestTypeDef,
    ArchiveRuleSummaryTypeDef,
    CancelPolicyGenerationRequestRequestTypeDef,
    CloudTrailDetailsTypeDef,
    CloudTrailPropertiesTypeDef,
    ConfigurationTypeDef,
    CreateAccessPreviewRequestRequestTypeDef,
    CreateAccessPreviewResponseTypeDef,
    CreateAnalyzerRequestRequestTypeDef,
    CreateAnalyzerResponseTypeDef,
    CreateArchiveRuleRequestRequestTypeDef,
    CriterionTypeDef,
    DeleteAnalyzerRequestRequestTypeDef,
    DeleteArchiveRuleRequestRequestTypeDef,
    FindingSourceDetailTypeDef,
    FindingSourceTypeDef,
    FindingSummaryTypeDef,
    FindingTypeDef,
    GeneratedPolicyPropertiesTypeDef,
    GeneratedPolicyResultTypeDef,
    GeneratedPolicyTypeDef,
    GetAccessPreviewRequestRequestTypeDef,
    GetAccessPreviewResponseTypeDef,
    GetAnalyzedResourceRequestRequestTypeDef,
    GetAnalyzedResourceResponseTypeDef,
    GetAnalyzerRequestRequestTypeDef,
    GetAnalyzerResponseTypeDef,
    GetArchiveRuleRequestRequestTypeDef,
    GetArchiveRuleResponseTypeDef,
    GetFindingRequestRequestTypeDef,
    GetFindingResponseTypeDef,
    GetGeneratedPolicyRequestRequestTypeDef,
    GetGeneratedPolicyResponseTypeDef,
    IamRoleConfigurationTypeDef,
    InlineArchiveRuleTypeDef,
    JobDetailsTypeDef,
    JobErrorTypeDef,
    KmsGrantConfigurationTypeDef,
    KmsGrantConstraintsTypeDef,
    KmsKeyConfigurationTypeDef,
    ListAccessPreviewFindingsRequestRequestTypeDef,
    ListAccessPreviewFindingsResponseTypeDef,
    ListAccessPreviewsRequestRequestTypeDef,
    ListAccessPreviewsResponseTypeDef,
    ListAnalyzedResourcesRequestRequestTypeDef,
    ListAnalyzedResourcesResponseTypeDef,
    ListAnalyzersRequestRequestTypeDef,
    ListAnalyzersResponseTypeDef,
    ListArchiveRulesRequestRequestTypeDef,
    ListArchiveRulesResponseTypeDef,
    ListFindingsRequestRequestTypeDef,
    ListFindingsResponseTypeDef,
    ListPolicyGenerationsRequestRequestTypeDef,
    ListPolicyGenerationsResponseTypeDef,
    ListTagsForResourceRequestRequestTypeDef,
    ListTagsForResourceResponseTypeDef,
    LocationTypeDef,
    NetworkOriginConfigurationTypeDef,
    PaginatorConfigTypeDef,
    PathElementTypeDef,
    PolicyGenerationDetailsTypeDef,
    PolicyGenerationTypeDef,
    PositionTypeDef,
    ResponseMetadataTypeDef,
    S3AccessPointConfigurationTypeDef,
    S3BucketAclGrantConfigurationTypeDef,
    S3BucketConfigurationTypeDef,
    S3PublicAccessBlockConfigurationTypeDef,
    SecretsManagerSecretConfigurationTypeDef,
    SortCriteriaTypeDef,
    SpanTypeDef,
    SqsQueueConfigurationTypeDef,
    StartPolicyGenerationRequestRequestTypeDef,
    StartPolicyGenerationResponseTypeDef,
    StartResourceScanRequestRequestTypeDef,
    StatusReasonTypeDef,
    SubstringTypeDef,
    TagResourceRequestRequestTypeDef,
    TrailPropertiesTypeDef,
    TrailTypeDef,
    UntagResourceRequestRequestTypeDef,
    UpdateArchiveRuleRequestRequestTypeDef,
    UpdateFindingsRequestRequestTypeDef,
    ValidatePolicyFindingTypeDef,
    ValidatePolicyRequestRequestTypeDef,
    ValidatePolicyResponseTypeDef,
    VpcConfigurationTypeDef,
)

def get_structure() -> AccessPreviewFindingTypeDef:
    return {
      ...
    }
```

## Versioning

`types-aiobotocore-accessanalyzer` version is the same as related `boto3`
version and follows [PEP 440](https://www.python.org/dev/peps/pep-0440/)
format.

## Documentation

All type annotations can be found in
[types-aiobotocore-accessanalyzer docs](https://vemel.github.io/types_aiobotocore_docs/types_aiobotocore_accessanalyzer/)

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
